@@ -8,7 +8,7 @@ package Inline::Java ;
 use strict ;
 require 5.006 ;
 
-$Inline::Java::VERSION = '0.51' ;
+$Inline::Java::VERSION = '0.52' ;
 
 
 # DEBUG is set via the DEBUG config
@@ -1021,6 +1021,11 @@ sub set_DONE {
 }
 
 
+sub __get_INLINES {
+	return \@INLINES ;
+}
+
+
 sub java2perl {
 	my $pkg = shift ;
 	my $jclass = shift ;
